@@ -102,6 +102,14 @@ class Test_create_cmap_overview(object):
     def test_lightness_profiles(self):
         create_cmap_overview(mpl_cmaps, plot_profile=True)
 
+    # Test if dark mode can be enabled for the overview
+    def test_dark_mode(self):
+        create_cmap_overview([cmrcm.rainforest], dark_mode=True)
+
+    # Test if the grayscale versions can be removed
+    def test_no_grayscale(self):
+        create_cmap_overview([cmrcm.rainforest], show_grayscale=False)
+
     # Test if providing a custom dict of colormaps works
     def test_dict(self):
         create_cmap_overview({'test1': [cmrcm.rainforest],
@@ -133,6 +141,13 @@ class Test_get_sub_cmap(object):
         assert np.allclose(sub_cmap(1.0), cmrcm.rainforest(204))
         assert (sub_cmap.N == 154)
 
+    # Test if a qualitative colormap can be made
+    def test_lilac_qual(self):
+        qual_cmap = get_sub_cmap('cmr.lilac', 0.2, 0.8, N=5)
+        assert np.allclose(qual_cmap(0.0), cmrcm.lilac(51))
+        assert np.allclose(qual_cmap(1.0), cmrcm.lilac(204))
+        assert (qual_cmap.N == 5)
+
     # Test if providing an incorrect range raises an error
     def test_invalid_range(self):
         with pytest.raises(ValueError):
@@ -162,6 +177,10 @@ class Test_import_cmaps(object):
     def test_cmap_file_8bit(self):
         import_cmaps(path.join(dirpath, 'data/cm_8bit.txt'))
 
+    # Test if providing a cmap .txt-file with HEX values works
+    def test_cmap_file_HEX(self):
+        import_cmaps(path.join(dirpath, 'data/cm_hex.txt'))
+
     # Test if providing a cmap .jscm-file works
     def test_cmap_file_jscm(self):
         cmap_path = path.join(dirpath, 'data/cm_rainforest_jscm.jscm')
@@ -171,7 +190,7 @@ class Test_import_cmaps(object):
     def test_cyclic_cmap(self):
         name = 'cyclic'
         import_cmaps(path.join(dirpath, 'data/cm_{0}.txt'.format(name)))
-        for cmap in [name, name+'_r', name+'_shifted', name+'_shifted_r']:
+        for cmap in [name, name+'_r', name+'_s', name+'_s_r']:
             assert 'cmr.'+cmap in plt.colormaps()
             assert getattr(cmrcm, cmap, None) is not None
             assert cmap in cmrcm.cmap_d
