@@ -258,8 +258,9 @@ def create_cmap_mod(cmap, *, save_dir='.'):
 
 # This function creates an overview plot of all colormaps specified
 def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
-                         sort='alphabetical', plot_profile=False,
-                         title="Colormap Overview"):
+                         sort='alphabetical', show_grayscale=True,
+                         plot_profile=False, dark_mode=False,
+                         title="Colormap Overview", wscale=1, hscale=1):
     """
     Creates an overview plot containing all colormaps defined in the provided
     `cmaps`.
@@ -290,15 +291,27 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
         :obj:`~matplotlib.colors.Colormap` object and returns the sorted
         position of that colormap.
         If *None*, the colormaps retain the order they were given in.
+    show_grayscale : bool. Default: True
+        Whether to show the grayscale versions of the given `cmaps` in the
+        overview.
     plot_profile : bool or float. Default: False
         Whether the lightness profiles of all colormaps should be plotted. If
         not *False*, the lightness profile of a colormap is plotted on top of
         its gray-scale version and `plot_profile` is used for setting the alpha
         (opacity) value.
         If `plot_profile` is *True*, it will be set to `0.25`.
+        If `show_grayscale` is *False*, this value is ignored.
+    dark_mode : bool. Default: False
+        Whether the colormap overview should be created using mostly dark
+        colors.
     title : str or None. Default: "Colormap Overview"
         String to be used as the title of the colormap overview.
         If empty or *None*, no title will be used.
+    wscale, hscale : float. Default: (1, 1)
+        Floats that determine with what factor the colormap subplot dimensions
+        in the overview should be scaled with.
+        The default values uses the default dimensions for the subplots (which
+        are determined by other input arguments).
 
     Notes
     -----
@@ -315,10 +328,37 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
 
     """
 
+    # Check value of show_grayscale
+    if show_grayscale:
+        # If True, the overview will have two columns
+        ncols = 2
+    else:
+        # If False, the overview will have one column and no profile plotted
+        ncols = 1
+        wscale *= 0.5
+        plot_profile = False
+
+    # Determine positions
+    wscale = 0.2+0.8*wscale
+    left_pos = 0.2/wscale
+    spacing = 0.01/wscale
+
     # If plot_profile is True, set it to its default value
     if plot_profile is True:
         plot_profile = 0.25
 
+    # Check if dark mode is requested
+    if dark_mode:
+        # If so, use dark grey for the background and light grey for the text
+        edge_color = '#24292E'
+        face_color = '#24292E'
+        text_color = '#9DA5B4'
+    else:
+        # If not, use white for the background and black for the text
+        edge_color = '#FFFFFF'
+        face_color = '#FFFFFF'
+        text_color = '#000000'
+
     # If cmaps is None, use cmap_d.values
     if cmaps is None:
         cmaps = cmrcm.cmap_d.values()
@@ -354,7 +394,7 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
             # Add empty list of colormaps to cmaps_dict with this cm_type
             cmaps_dict[cm_type] = []
 
-            # Loop over all cmaps and remove reversed versions
+            # Loop over all cmaps and add their Colormap objects
             for cmap in cmaps:
                 if isinstance(cmap, str):
                     cmaps_dict[cm_type].append(mplcm.get_cmap(cmap))
@@ -370,7 +410,7 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
                         'misc']
             cmaps_dict = odict([[cm_type, []] for cm_type in cm_types])
 
-            # Loop over all cmaps and remove reversed versions
+            # Loop over all cmaps and add their Colormap objects
             for cmap in cmaps:
                 cm_type = get_cmap_type(cmap)
                 if isinstance(cmap, str):
@@ -378,7 +418,7 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
                 else:
                     cmaps_dict[cm_type].append(cmap)
         else:
-            # Loop over all cmaps and remove reversed versions
+            # Loop over all cmaps and add their Colormap objects
             for cmap in cmaps:
                 if isinstance(cmap, str):
                     cmaps_list.append(mplcm.get_cmap(cmap))
@@ -431,40 +471,55 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
     cspace_convert = cspace_converter("sRGB1", "CAM02-UCS")
 
     # Create figure instance
-    height = 0.4*len(cmaps_list)+0.1
-    fig, axs = plt.subplots(figsize=(6.4, height), nrows=len(cmaps_list),
-                            ncols=2)
+    height = (0.4*len(cmaps_list)+0.1)*hscale
+    fig, axs = plt.subplots(figsize=(6.4*wscale, height),
+                            nrows=len(cmaps_list), ncols=ncols,
+                            edgecolor=edge_color, facecolor=face_color)
 
     # Adjust subplot positioning
-    fig.subplots_adjust(top=(1-0.05/height), bottom=0.05/height, left=0.2,
-                        right=0.99, wspace=0.05)
+    fig.subplots_adjust(top=(1-0.05/height), bottom=0.05/height, left=left_pos,
+                        right=1.0-spacing, wspace=0.05)
 
     # If cmaps_list only has a single element, make sure axs is a list
     if(len(cmaps_list) == 1):
         axs = [axs]
 
     # Loop over all cmaps defined in cmaps list
-    for (ax0, ax1), cmap in zip(axs, cmaps_list):
-        # Turn axes off
-        ax0.set_axis_off()
-        ax1.set_axis_off()
+    for ax, cmap in zip(axs, cmaps_list):
+        # Obtain axes objects and turn them off
+        if show_grayscale:
+            # Obtain Axes objects
+            ax0, ax1 = ax
+
+            # Turn axes off
+            ax0.set_axis_off()
+            ax1.set_axis_off()
+        else:
+            # Obtain Axes object
+            ax0 = ax
+
+            # Turn axis off
+            ax0.set_axis_off()
 
         # Obtain position bbox of ax0
         pos0 = ax0.get_position()
 
         # If cmap is a tuple, it defines a title or cm_type
         if isinstance(cmap, tuple):
+            # Calculate title_pos
+            title_pos = left_pos+(1-spacing-left_pos)/2
+
             # If it is a title
             if cmap[1]:
                 # Write the title as text in the correct position
-                fig.text(0.595, pos0.y0+pos0.height/2, cmap[0],
-                         va='center', ha='center', fontsize=18)
+                fig.text(title_pos, pos0.y0+pos0.height/2, cmap[0],
+                         va='center', ha='center', fontsize=18, c=text_color)
 
             # If it is a cm_type
             else:
                 # Write the cm_type as text in the correct position
-                fig.text(0.595, pos0.y0, cmap[0],
-                         va='bottom', ha='center', fontsize=14)
+                fig.text(title_pos, pos0.y0, cmap[0],
+                         va='bottom', ha='center', fontsize=14, c=text_color)
 
         # Else, this is a colormap
         else:
@@ -534,19 +589,21 @@ def create_cmap_overview(cmaps=None, *, savefig=None, use_types=True,
                 # Add line-collection to this subplot
                 ax1.add_collection(lc)
 
-            # Add gray-scale colormap subplot
-            ax1.imshow(rgb_L[np.newaxis, ...], aspect='auto')
+            # Add gray-scale colormap subplot if requested
+            if show_grayscale:
+                ax1.imshow(rgb_L[np.newaxis, ...], aspect='auto')
 
             # Plot the name of the colormap as text
-            x_text = pos0.x0-0.01
+            x_text = pos0.x0-spacing
             y_text = pos0.y0+pos0.height/2
             fig.text(x_text, y_text, cmap.name,
-                     va='center', ha='right', fontsize=10)
+                     va='center', ha='right', fontsize=10, c=text_color)
 
     # If savefig is not None, save the figure
     if savefig is not None:
         dpi = 100 if (path.splitext(savefig)[1] == '.svg') else 250
-        plt.savefig(savefig, dpi=dpi)
+        plt.savefig(savefig, dpi=dpi, facecolor=face_color,
+                    edgecolor=edge_color)
         plt.close(fig)
 
     # Else, simply show it
@@ -672,15 +729,15 @@ def get_cmap_type(cmap):
 
 
 # Function create a colormap using a subset of the colors in an existing one
-def get_sub_cmap(cmap, start, stop):
+def get_sub_cmap(cmap, start, stop, *, N=None):
     """
     Creates a :obj:`~matplotlib.cm.ListedColormap` object using the colors in
     the range `[start, stop]` of the provided `cmap` and returns it.
 
     This function can be used to create a colormap that only uses a portion of
     an existing colormap.
-
-    .. versionadded:: 1.3.2
+    If `N` is not set to *None*, this function creates a qualitative colormap
+    from `cmap` instead.
 
     Parameters
     ----------
@@ -688,13 +745,21 @@ def get_sub_cmap(cmap, start, stop):
         The registered name of the colormap in :mod:`matplotlib.cm` or its
         corresponding :obj:`~matplotlib.colors.Colormap` object.
     start, stop : float
-        The normalized range of the colors in `cmap` that must be in the sub
-        colormap.
+        The normalized range of the colors in `cmap` that must be in the
+        sub-colormap.
+
+    Optional
+    --------
+    N : int or None. Default: None
+        The number of color segments to take from the provided `cmap` within
+        the range given by the provided `start` and `stop`.
+        If *None*, take all colors in `cmap` within this range.
 
     Returns
     -------
     sub_cmap : :obj:`~matplotlib.colors.ListedColormap`
         The created colormap that uses a subset of the colors in `cmap`.
+        If `N` is not *None*, this will be a qualitative colormap.
 
     Example
     -------
@@ -702,6 +767,11 @@ def get_sub_cmap(cmap, start, stop):
 
         >>> get_sub_cmap('cmr.rainforest', 0, 0.8)
 
+    Creating a qualitative colormap containing five colors from the middle 60%
+    of the 'lilac' colormap:
+
+        >>> get_sub_cmap('cmr.lilac', 0.2, 0.8, N=5)
+
     Notes
     -----
     As it can create artifacts, this function does not interpolate between the
@@ -722,11 +792,14 @@ def get_sub_cmap(cmap, start, stop):
     # Obtain the colormap
     cmap = mplcm.get_cmap(cmap)
 
+    # Check value of N to determine suffix for the name
+    suffix = '_sub' if N is None else '_qual'
+
     # Obtain colors
-    colors = take_cmap_colors(cmap, None, cmap_range=(start, stop))
+    colors = take_cmap_colors(cmap, N, cmap_range=(start, stop))
 
     # Create new colormap
-    sub_cmap = LC(colors, cmap.name+'_sub', N=len(colors))
+    sub_cmap = LC(colors, cmap.name+suffix, N=len(colors))
 
     # Return sub_cmap
     return(sub_cmap)
@@ -742,7 +815,7 @@ def import_cmaps(cmap_path):
     Both the imported colormap and its reversed version will be registered.
 
     If a provided colormap is a 'cyclic' colormap, its shifted version will
-    also be registered.
+    also be registered with the `_s` suffix.
 
     Parameters
     ----------
@@ -857,7 +930,7 @@ def import_cmaps(cmap_path):
                 rgb_s = np.concatenate([rgb[idx:], rgb[:idx]], axis=0)
 
                 # Register this colormap as well
-                register_cmap(cm_name+'_shifted', rgb_s)
+                register_cmap(cm_name+'_s', rgb_s)
 
         # If any error is raised, reraise it
         except Exception as error:
@@ -988,16 +1061,15 @@ def take_cmap_colors(cmap, N, *, cmap_range=(0, 1), return_fmt='float'):
     Takes `N` equally spaced colors from the provided colormap `cmap` and
     returns them.
 
-    .. versionadded:: 1.3.2
-
     Parameters
     ----------
     cmap : str or :obj:`~matplotlib.colors.Colormap` object
         The registered name of the colormap in :mod:`matplotlib.cm` or its
         corresponding :obj:`~matplotlib.colors.Colormap` object.
     N : int or None
-        The number of colors to take from the provided `cmap`.
-        If *None*, take all colors in `cmap` within the provided `cmap_range`.
+        The number of colors to take from the provided `cmap` within the given
+        `cmap_range`.
+        If *None*, take all colors in `cmap` within this range.
 
     Optional
     --------
